@@ -9,6 +9,7 @@
 
 package org.gnu.gnome;
 import org.gnu.glib.Boxed;
+import org.gnu.glib.Handle;
 public class GConf extends Boxed 
 {
 	public static String getGnomeLibsSettings(String subkey) {
@@ -19,13 +20,9 @@ public class GConf extends Boxed
 		return gnome_gconf_get_app_settings_relative(program.getHandle(), subkey);
 	}
 	
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
+
     native static final protected String gnome_gconf_get_gnome_libs_settings_relative (String subkey);
-    native static final protected String gnome_gconf_get_app_settings_relative (int program, String subkey);
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
+    native static final protected String gnome_gconf_get_app_settings_relative (Handle program, String subkey);
+
 }
 
