@@ -31,7 +31,7 @@ public class IconTextItem extends CanvasItem {
 	
 	public Editable getEditable() {
 		Handle hndl = gnome_icon_text_item_get_editable(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Entry)obj;
 		return new Entry(hndl);
