@@ -8,8 +8,9 @@
  */
 
 #include <jni.h>
-#include <sys/types.h>
-#include <gnome.h>
+#include <libgnomecanvas/libgnomecanvas.h>
+#include <jg_jnu.h>
+
 #ifdef __cplusplus
 extern "C" 
 {
@@ -23,13 +24,12 @@ GnomeCanvas * GnomeCanvasItem_get_canvas (GnomeCanvasItem * cptr)
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    getCanvas
- * Signature: (I)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasItem_getCanvas (JNIEnv *env, jclass cls, jint 
+JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasItem_getCanvas (JNIEnv *env, jclass cls, jobject 
     cptr) 
 {
-    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)cptr;
-    return (jint)GnomeCanvasItem_get_canvas (cptr_g);
+    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)getPointerFromHandle(env, cptr);
+    return getHandleFromPointer(env, GnomeCanvasItem_get_canvas (cptr_g));
 }
 
 GnomeCanvasItem * GnomeCanvasItem_get_parent (GnomeCanvasItem * cptr) 
@@ -40,15 +40,12 @@ GnomeCanvasItem * GnomeCanvasItem_get_parent (GnomeCanvasItem * cptr)
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    getParent
- * Signature: (I)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasItem_getParent (JNIEnv *env, jclass cls, jint 
+JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasItem_getParent (JNIEnv *env, jclass cls, jobject 
     cptr) 
 {
-    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)cptr;
-    {
-        return (jint)GnomeCanvasItem_get_parent (cptr_g);
-    }
+    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)getPointerFromHandle(env, cptr);
+    return getHandleFromPointer(env, GnomeCanvasItem_get_parent (cptr_g));
 }
 
 gdouble GnomeCanvasItem_get_x1 (GnomeCanvasItem * cptr) 
@@ -59,16 +56,12 @@ gdouble GnomeCanvasItem_get_x1 (GnomeCanvasItem * cptr)
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    getX1
- * Signature: (I)D
  */
-JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getX1 (JNIEnv *env, jclass cls, jint 
+JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getX1 (JNIEnv *env, jclass cls, jobject 
     cptr) 
 {
-    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)cptr;
-    {
-        jdouble result_j = (jdouble) (GnomeCanvasItem_get_x1 (cptr_g));
-        return result_j;
-    }
+    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)getPointerFromHandle(env, cptr);
+    return (jdouble) (GnomeCanvasItem_get_x1 (cptr_g));
 }
 
 gdouble GnomeCanvasItem_get_y1 (GnomeCanvasItem * cptr) 
@@ -79,16 +72,12 @@ gdouble GnomeCanvasItem_get_y1 (GnomeCanvasItem * cptr)
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    getY1
- * Signature: (I)D
  */
-JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getY1 (JNIEnv *env, jclass cls, jint 
+JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getY1 (JNIEnv *env, jclass cls, jobject 
     cptr) 
 {
-    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)cptr;
-    {
-        jdouble result_j = (jdouble) (GnomeCanvasItem_get_y1 (cptr_g));
-        return result_j;
-    }
+    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)getPointerFromHandle(env, cptr);
+    return (jdouble) (GnomeCanvasItem_get_y1 (cptr_g));
 }
 
 gdouble GnomeCanvasItem_get_x2 (GnomeCanvasItem * cptr) 
@@ -99,16 +88,12 @@ gdouble GnomeCanvasItem_get_x2 (GnomeCanvasItem * cptr)
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    getX2
- * Signature: (I)D
  */
-JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getX2 (JNIEnv *env, jclass cls, jint 
+JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getX2 (JNIEnv *env, jclass cls, jobject 
     cptr) 
 {
-    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)cptr;
-    {
-        jdouble result_j = (jdouble) (GnomeCanvasItem_get_x2 (cptr_g));
-        return result_j;
-    }
+    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)getPointerFromHandle(env, cptr);
+    return (jdouble) (GnomeCanvasItem_get_x2 (cptr_g));
 }
 
 gdouble GnomeCanvasItem_get_y2 (GnomeCanvasItem * cptr) 
@@ -119,250 +104,200 @@ gdouble GnomeCanvasItem_get_y2 (GnomeCanvasItem * cptr)
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    getY2
- * Signature: (I)D
  */
-JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getY2 (JNIEnv *env, jclass cls, jint 
+JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getY2 (JNIEnv *env, jclass cls, jobject 
     cptr) 
 {
-    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)cptr;
-    {
-        jdouble result_j = (jdouble) (GnomeCanvasItem_get_y2 (cptr_g));
-        return result_j;
-    }
+    GnomeCanvasItem *cptr_g = (GnomeCanvasItem *)getPointerFromHandle(env, cptr);
+    return (jdouble) (GnomeCanvasItem_get_y2 (cptr_g));
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_get_type
- * Signature: ()I
  */
 JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1get_1type (JNIEnv 
     *env, jclass cls) 
 {
-    {
-        return (jint)gnome_canvas_item_get_type ();
-    }
+    return (jint)gnome_canvas_item_get_type ();
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_move
- * Signature: (IDD)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1move (JNIEnv *env, 
-    jclass cls, jint item, jdouble dx, jdouble dy) 
+    jclass cls, jobject item, jdouble dx, jdouble dy) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
     gdouble dx_g = (gdouble) dx;
     gdouble dy_g = (gdouble) dy;
-    {
-        gnome_canvas_item_move (item_g, dx_g, dy_g);
-    }
+    gnome_canvas_item_move (item_g, dx_g, dy_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_affine_relative
- * Signature: (I[Ldouble ;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1affine_1relative (
-    JNIEnv *env, jclass cls, jint item, jdoubleArray affine) 
+    JNIEnv *env, jclass cls, jobject item, jdoubleArray affine) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
     gdouble *affine_g = (gdouble *) (*env)->GetDoubleArrayElements (env, affine, NULL);
-    {
-        gnome_canvas_item_affine_relative (item_g, affine_g);
-        (*env)->ReleaseDoubleArrayElements (env, affine, (jdouble *) affine_g, 0);
-    }
+    gnome_canvas_item_affine_relative (item_g, affine_g);
+    (*env)->ReleaseDoubleArrayElements (env, affine, (jdouble *) affine_g, 0);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_affine_absolute
- * Signature: (I[Ldouble ;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1affine_1absolute (
-    JNIEnv *env, jclass cls, jint item, jdoubleArray affine) 
+    JNIEnv *env, jclass cls, jobject item, jdoubleArray affine) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
     gdouble *affine_g = (gdouble *) (*env)->GetDoubleArrayElements (env, affine, NULL);
-    {
-        gnome_canvas_item_affine_absolute (item_g, affine_g);
-        (*env)->ReleaseDoubleArrayElements (env, affine, (jdouble *) affine_g, 0);
-    }
+    gnome_canvas_item_affine_absolute (item_g, affine_g);
+    (*env)->ReleaseDoubleArrayElements (env, affine, (jdouble *) affine_g, 0);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_raise
- * Signature: (II)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1raise (JNIEnv *env, 
-    jclass cls, jint item, jint position) 
+    jclass cls, jobject item, jint position) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
     gint32 position_g = (gint32) position;
-    {
-        gnome_canvas_item_raise (item_g, position_g);
-    }
+    gnome_canvas_item_raise (item_g, position_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_raise_to_top
- * Signature: (I)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1raise_1to_1top (
-    JNIEnv *env, jclass cls, jint item) 
+    JNIEnv *env, jclass cls, jobject item) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
-    {
-        gnome_canvas_item_raise_to_top (item_g);
-    }
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
+    gnome_canvas_item_raise_to_top (item_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_lower
- * Signature: (II)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1lower (JNIEnv *env, 
-    jclass cls, jint item, jint positions) 
+    jclass cls, jobject item, jint positions) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
     gint32 positions_g = (gint32) positions;
-    {
-        gnome_canvas_item_lower (item_g, positions_g);
-    }
+    gnome_canvas_item_lower (item_g, positions_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_lower_to_bottom
- * Signature: (I)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1lower_1to_1bottom (
-    JNIEnv *env, jclass cls, jint item) 
+    JNIEnv *env, jclass cls, jobject item) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
-    {
-        gnome_canvas_item_lower_to_bottom (item_g);
-    }
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
+    gnome_canvas_item_lower_to_bottom (item_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_show
- * Signature: (I)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1show (JNIEnv *env, 
-    jclass cls, jint item) 
+    jclass cls, jobject item) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
-    {
-        gnome_canvas_item_show (item_g);
-    }
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
+    gnome_canvas_item_show (item_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_hide
- * Signature: (I)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1hide (JNIEnv *env, 
-    jclass cls, jint item) 
+    jclass cls, jobject item) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
-    {
-        gnome_canvas_item_hide (item_g);
-    }
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
+    gnome_canvas_item_hide (item_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_grab
- * Signature: (IIII)I
  */
 JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1grab (JNIEnv *env, 
-    jclass cls, jint item, jint event_mask, jint cursor, jint etime) 
+    jclass cls, jobject item, jint event_mask, jobject cursor, jint etime) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
     gint32 event_mask_g = (gint32) event_mask;
-    GdkCursor *cursor_g = (GdkCursor *)cursor;
+    GdkCursor *cursor_g = (GdkCursor *)getPointerFromHandle(env, cursor);
     gint32 etime_g = (gint32) etime;
-    {
-        jint result_j = (jint) (gnome_canvas_item_grab (item_g, event_mask_g, cursor_g, etime_g));
-        return result_j;
-    }
+    return (jint)gnome_canvas_item_grab (item_g, event_mask_g, cursor_g, etime_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_ungrab
- * Signature: (II)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1ungrab (JNIEnv *env, 
-    jclass cls, jint item, jint etime) 
+    jclass cls, jobject item, jint etime) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
     gint32 etime_g = (gint32) etime;
-    {
-        gnome_canvas_item_ungrab (item_g, etime_g);
-    }
+    gnome_canvas_item_ungrab (item_g, etime_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_reparent
- * Signature: (II)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1reparent (JNIEnv 
-    *env, jclass cls, jint item, jint new_group) 
+    *env, jclass cls, jobject item, jobject new_group) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
-    GnomeCanvasGroup *new_group_g = (GnomeCanvasGroup *)new_group;
-    {
-        gnome_canvas_item_reparent (item_g, new_group_g);
-    }
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
+    GnomeCanvasGroup *new_group_g = (GnomeCanvasGroup *)getPointerFromHandle(env, new_group);
+    gnome_canvas_item_reparent (item_g, new_group_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_grab_focus
- * Signature: (I)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1grab_1focus (JNIEnv 
-    *env, jclass cls, jint item) 
+    *env, jclass cls, jobject item) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
-    {
-        gnome_canvas_item_grab_focus (item_g);
-    }
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
+    gnome_canvas_item_grab_focus (item_g);
 }
 
 /*
  * Class:     org.gnu.gnome.CanvasItem
  * Method:    gnome_canvas_item_request_update
- * Signature: (I)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1request_1update (
-    JNIEnv *env, jclass cls, jint item) 
+    JNIEnv *env, jclass cls, jobject item) 
 {
-    GnomeCanvasItem *item_g = (GnomeCanvasItem *)item;
-    {
-        gnome_canvas_item_request_update (item_g);
-    }
+    GnomeCanvasItem *item_g = (GnomeCanvasItem *)getPointerFromHandle(env, item);
+    gnome_canvas_item_request_update (item_g);
 }
 
 /*
  * Class:     org_gnu_gnome_CanvasItem
  * Method:    gnome_canvas_item_new
- * Signature: (II)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1new
-  (JNIEnv *env, jclass cls, jint group, jint type)
+JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasItem_gnome_1canvas_1item_1new
+  (JNIEnv *env, jclass cls, jobject group, jint type)
 {
-	return (jint)gnome_canvas_item_new((GnomeCanvasGroup*)group, (GType)type, NULL);
+    GnomeCanvasGroup *group_g = (GnomeCanvasGroup *)getPointerFromHandle(env, group);
+	return getHandleFromPointer(env, gnome_canvas_item_new(group_g, (GType)type, NULL));
 }
                                                                               
 
